@@ -15,9 +15,10 @@ extern "C" {
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <sharing-plugin-interface.h>
-//#include <sharing-transfer.h>
+#include <sharing-service-option.h>
 #include <conicconnection.h>
 #include <osso-log.h>
+#include <hildon/hildon.h>
 
 #include "send.h"
 #include "validate.h"
@@ -36,7 +37,10 @@ sharing_plugin_interface_account_validate (SharingAccount* account,
 SharingPluginInterfaceEditAccountResult
     sharing_plugin_interface_edit_account (GtkWindow* parent,
     SharingAccount* account, ConIcConnection* con, gboolean* dead_mans_switch);
-
+SharingPluginInterfaceAccountSetupResult
+create_ui (GtkWindow* parent,
+           SharingAccount* worked_on,
+           gboolean isEdit);
 
 #ifdef	__cplusplus
 }
